List of VARNA parameters and their default value that can be passed as keyword arguments to `BasicDraw.update()`.
The name of keyword argument is listed in the `name` column in each table.


::: varnaapi.param
    selection:
		  members: ["COLOR_LIST", "BOOLEAN_OPTIONS", "NUMERIC_PARAMS"]

# Choices
There are two VARNA parameters, `algorithm` and `bpStyle`, takes value from defined options.
::: varnaapi.param
    selection:
		  members: ["BP_STYLES", "ALGORITHMS"]

